import { __decorate } from "tslib";
import { ErrorBoundaryEvent, showError } from '@genesislcap/foundation-errors';
import { createLogger } from '@genesislcap/foundation-utils';
import { observable } from '@microsoft/fast-element';
import { FoundationElement } from '@microsoft/fast-foundation';
import { foundationErrorBoundaryTemplate as template } from './error-boundary.template';
export const foundationErrorBoundaryShadowOptions = {
    mode: 'open',
    delegatesFocus: true,
};
/**
 * @tagname %%prefix%%-error-boundary
 */
export class ErrorBoundary extends FoundationElement {
    constructor() {
        super(...arguments);
        this.logger = createLogger('error-boundary');
    }
    connectedCallback() {
        super.connectedCallback();
        this.addEventListener(ErrorBoundaryEvent.ERROR_BOUNDARY_EVENT, (e) => {
            e.stopImmediatePropagation();
            showError(e.detail, this.tagName, this.errorBoundary);
        });
    }
}
__decorate([
    observable
], ErrorBoundary.prototype, "errorBoundary", void 0);
/**
 * The Foundation Error Boundary
 *
 * @public
 * @remarks
 * HTML Element: \<foundation-error-boundary\>
 */
export const foundationErrorBoundary = ErrorBoundary.compose({
    baseName: 'error-boundary',
    template,
    shadowOptions: foundationErrorBoundaryShadowOptions,
});
